@@ -143,7 +143,7 @@ func (r *Reader) _wait() error {
 
 func TestGetLines(t *testing.T) {
 	for _, file := range getTestFiles(t) {
-		reader, err := NewReaderFromFilename(file, *styles.Get("native"), formatters.TTY16m, nil)
+		reader, err := NewReaderFromFilename(file, formatters.TTY16m, ReaderOptions{Style: styles.Get("native")})
 		if err != nil {
 			t.Errorf("Error opening file <%s>: %s", file, err.Error())
 			continue
@@ -197,7 +197,7 @@ func testHighlightingLineCount(t *testing.T, filenameWithPath string) {
 	}
 
 	// Then load the same file using one of our Readers
-	reader, err := NewReaderFromFilename(filenameWithPath, *styles.Get("native"), formatters.TTY16m, nil)
+	reader, err := NewReaderFromFilename(filenameWithPath, formatters.TTY16m, ReaderOptions{Style: styles.Get("native")})
 	assert.NilError(t, err)
 	err = reader._wait()
 	assert.NilError(t, err)
@@ -208,7 +208,7 @@ func testHighlightingLineCount(t *testing.T, filenameWithPath string) {
 
 func TestGetLongLine(t *testing.T) {
 	file := "../sample-files/very-long-line.txt"
-	reader, err := NewReaderFromFilename(file, *styles.Get("native"), formatters.TTY16m, nil)
+	reader, err := NewReaderFromFilename(file, formatters.TTY16m, ReaderOptions{Style: styles.Get("native")})
 	assert.NilError(t, err)
 	assert.NilError(t, reader._wait())
 
@@ -253,7 +253,7 @@ func TestStatusText(t *testing.T) {
 	testStatusText(t, linenumbers.LineNumber{}, linenumbers.LineNumber{}, 1, "1 line  100%")
 
 	// Test with filename
-	testMe, err := NewReaderFromFilename(samplesDir+"/empty", *styles.Get("native"), formatters.TTY16m, nil)
+	testMe, err := NewReaderFromFilename(samplesDir+"/empty", formatters.TTY16m, ReaderOptions{Style: styles.Get("native")})
 	assert.NilError(t, err)
 	assert.NilError(t, testMe._wait())
 
@@ -267,7 +267,7 @@ func TestStatusText(t *testing.T) {
 
 func testCompressedFile(t *testing.T, filename string) {
 	filenameWithPath := path.Join(samplesDir, filename)
-	reader, e := NewReaderFromFilename(filenameWithPath, *styles.Get("native"), formatters.TTY16m, nil)
+	reader, e := NewReaderFromFilename(filenameWithPath, formatters.TTY16m, ReaderOptions{Style: styles.Get("native")})
 	if e != nil {
 		t.Errorf("Error opening file <%s>: %s", filenameWithPath, e.Error())
 		panic(e)
@@ -288,7 +288,7 @@ func TestCompressedFiles(t *testing.T) {
 
 func TestReadFileDoneNoHighlighting(t *testing.T) {
 	testMe, err := NewReaderFromFilename(samplesDir+"/empty",
-		*styles.Get("Native"), formatters.TTY, nil)
+		formatters.TTY, ReaderOptions{Style: styles.Get("native")})
 	assert.NilError(t, err)
 
 	assert.NilError(t, testMe._wait())
@@ -296,14 +296,14 @@ func TestReadFileDoneNoHighlighting(t *testing.T) {
 
 func TestReadFileDoneYesHighlighting(t *testing.T) {
 	testMe, err := NewReaderFromFilename("reader_test.go",
-		*styles.Get("Native"), formatters.TTY, nil)
+		formatters.TTY, ReaderOptions{Style: styles.Get("native")})
 	assert.NilError(t, err)
 
 	assert.NilError(t, testMe._wait())
 }
 
 func TestReadStreamDoneNoHighlighting(t *testing.T) {
-	testMe := NewReaderFromStream("", strings.NewReader("Johan"), chroma.Style{}, nil, nil)
+	testMe := NewReaderFromStream("", strings.NewReader("Johan"), nil, ReaderOptions{Style: &chroma.Style{}})
 
 	assert.NilError(t, testMe._wait())
 }
@@ -311,7 +311,7 @@ func TestReadStreamDoneNoHighlighting(t *testing.T) {
 func TestReadStreamDoneYesHighlighting(t *testing.T) {
 	testMe := NewReaderFromStream("",
 		strings.NewReader("Johan"),
-		*styles.Get("Native"), formatters.TTY, lexers.EmacsLisp)
+		formatters.TTY, ReaderOptions{Lexer: lexers.EmacsLisp, Style: styles.Get("native")})
 
 	assert.NilError(t, testMe._wait())
 }
@@ -322,6 +322,27 @@ func TestReadTextDone(t *testing.T) {
 	assert.NilError(t, testMe._wait())
 }
 
+// JSON should be auto detected and formatted
+func TestFormatJson(t *testing.T) {
+	jsonStream := strings.NewReader(`{"key": "value"}`)
+	testMe := NewReaderFromStream(
+		"JSON test",
+		jsonStream,
+		formatters.TTY,
+		ReaderOptions{
+			Style:        styles.Get("native"),
+			ShouldFormat: true,
+		})
+
+	assert.NilError(t, testMe._wait())
+
+	lines, _ := testMe.GetLines(linenumbers.LineNumber{}, 10)
+	assert.Equal(t, lines.lines[0].Plain(nil), "{")
+	assert.Equal(t, lines.lines[1].Plain(nil), `  "key": "value"`)
+	assert.Equal(t, lines.lines[2].Plain(nil), "}")
+	assert.Equal(t, len(lines.lines), 3)
+}
+
 // If people keep appending to the currently opened file we should display those
 // changes.
 func TestReadUpdatingFile(t *testing.T) {
@@ -335,7 +356,7 @@ func TestReadUpdatingFile(t *testing.T) {
 	assert.NilError(t, err)
 
 	// Start a reader on that file
-	testMe, err := NewReaderFromFilename(file.Name(), *styles.Get("native"), formatters.TTY16m, nil)
+	testMe, err := NewReaderFromFilename(file.Name(), formatters.TTY16m, ReaderOptions{Style: styles.Get("native")})
 	assert.NilError(t, err)
 
 	// Wait for the reader to finish reading
@@ -408,7 +429,7 @@ func TestReadUpdatingFile_InitiallyEmpty(t *testing.T) {
 	defer os.Remove(file.Name())
 
 	// Start a reader on that file
-	testMe, err := NewReaderFromFilename(file.Name(), *styles.Get("native"), formatters.TTY16m, nil)
+	testMe, err := NewReaderFromFilename(file.Name(), formatters.TTY16m, ReaderOptions{Style: styles.Get("native")})
 	assert.NilError(t, err)
 
 	// Wait for the reader to finish reading
@@ -453,7 +474,7 @@ func TestReadUpdatingFile_HalfLine(t *testing.T) {
 	assert.NilError(t, err)
 
 	// Start a reader on that file
-	testMe, err := NewReaderFromFilename(file.Name(), *styles.Get("native"), formatters.TTY16m, nil)
+	testMe, err := NewReaderFromFilename(file.Name(), formatters.TTY16m, ReaderOptions{Style: styles.Get("native")})
 	assert.NilError(t, err)
 
 	// Wait for the reader to finish reading
@@ -498,7 +519,7 @@ func TestReadUpdatingFile_HalfUtf8(t *testing.T) {
 	assert.NilError(t, err)
 
 	// Start a reader on that file
-	testMe, err := NewReaderFromFilename(file.Name(), *styles.Get("native"), formatters.TTY16m, nil)
+	testMe, err := NewReaderFromFilename(file.Name(), formatters.TTY16m, ReaderOptions{Style: styles.Get("native")})
 	assert.NilError(t, err)
 
 	// Wait for the reader to finish reading
@@ -537,7 +558,7 @@ func BenchmarkReaderDone(b *testing.B) {
 	b.ResetTimer()
 	for n := 0; n < b.N; n++ {
 		// This is our longest .go file
-		readMe, err := NewReaderFromFilename(filename, *styles.Get("native"), formatters.TTY16m, nil)
+		readMe, err := NewReaderFromFilename(filename, formatters.TTY16m, ReaderOptions{Style: styles.Get("native")})
 		assert.NilError(b, err)
 
 		assert.NilError(b, readMe._wait())
@@ -572,7 +593,7 @@ func BenchmarkReadLargeFile(b *testing.B) {
 
 	b.ResetTimer()
 	for n := 0; n < b.N; n++ {
-		readMe, err := NewReaderFromFilename(largeFileName, *styles.Get("native"), formatters.TTY16m, nil)
+		readMe, err := NewReaderFromFilename(largeFileName, formatters.TTY16m, ReaderOptions{Style: styles.Get("native")})
 		assert.NilError(b, err)
 
 		assert.NilError(b, readMe._wait())
