@@ -14,6 +14,10 @@ import (
 	"golang.org/x/term"
 )
 
+// NOTE: Karma points for replacing TestInterruptableReader_blockedOnRead() with
+// TestInterruptableReader_blockedOnReadImmediate() and fixing the Windows
+// implementation here so that the tests pass.
+
 type interruptableReaderImpl struct {
 	base              *os.File
 	shutdownRequested atomic.Bool
@@ -37,6 +41,7 @@ func (r *interruptableReaderImpl) Read(p []byte) (n int, err error) {
 
 	if r.shutdownRequested.Load() {
 		err = io.EOF
+		n = 0
 	}
 	return
 }
@@ -55,10 +60,6 @@ func (r *interruptableReaderImpl) Interrupt() {
 	r.shutdownRequested.Store(true)
 }
 
-func (r *interruptableReaderImpl) Close() error {
-	return nil
-}
-
 func newInterruptableReader(base *os.File) (interruptableReader, error) {
 	return &interruptableReaderImpl{base: base}, nil
 }
