@@ -7,6 +7,7 @@ import (
 	"io"
 	"os"
 	"os/signal"
+	"runtime/debug"
 	"sync/atomic"
 	"syscall"
 
@@ -117,6 +118,10 @@ func (screen *UnixScreen) setupSigwinchNotification() {
 	sigwinch := make(chan os.Signal, 1)
 	signal.Notify(sigwinch, syscall.SIGWINCH)
 	go func() {
+		defer func() {
+			panicHandler("setupSigwinchNotification()/SIGWINCH", recover(), debug.Stack())
+		}()
+
 		for {
 			// Await window resize signal
 			<-sigwinch
